@@ -1,11 +1,11 @@
 #!/usr/bin/perl
-
+use oEdtk;
 use oEdtk::Config	qw(config_read);
 use oEdtk::DBAdmin	qw(db_connect move_table);
 use warnings;
 use strict;
 
-if (@ARGV < 2) {
+if (@ARGV < 2 or $ARGV[0] =~/-h/i) {
 	die "Usage: $0 table_source table_cible [-create]\n";
 }
 
